ETS-backed registry mapping session IDs to registered view callback IDs.
Tracks which SnakeBridge callbacks belong to which Slither session so they can be cleaned up when a session ends.
Summary
Functions
Returns a specification to start this module under a supervisor.
Remove all registrations for a session.
Get all callback registrations for a session.
Register a view callback for a session (or :global).
Functions
Returns a specification to start this module under a supervisor.
See Supervisor.
@spec clear_session(binary() | :global) :: :ok
Remove all registrations for a session.
Get all callback registrations for a session.
Register a view callback for a session (or :global).